@@ -1,11 +1,15 @@
 package Finance::Bitcoin::Wallet;
 
+use 5.010;
+use common::sense;
 use Carp;
 use Class::Accessor 'antlers';
 use Finance::Bitcoin;
 use Scalar::Util qw[blessed];
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
+
+BEGIN { foreach my $method (qw[api]) { eval "sub $method {}" } } # make visible to Pod::Coverage
 
 has api => (is => 'rw');
 
@@ -132,6 +136,10 @@ other people to send money to this wallet. $label is an optional
 human-friendly name for the address. Returns a Finance::Bitcoin::Address
 object.
 
+=item C<< api >>
+
+Retrieve a reference to the L<Finance::Bitcoin::API> object being used. 
+
 =back
 
 =head1 BUGS
@@ -150,7 +158,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2010 Toby Inkster
+Copyright 2010-2011 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
